<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/core/RUnit.cpp" line="+273"/>
        <source>None</source>
        <translation>Nič</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Inch</source>
        <translation>Palec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Foot</source>
        <translation>Stopa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mile</source>
        <translation>Míľa</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Millimeter</source>
        <translation>Milimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Centimeter</source>
        <translation>Centimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Meter</source>
        <translation>Meter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Kilometer</source>
        <translation>Kilometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Microinch</source>
        <translation>Mikropalec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Mil</source>
        <translation>Tisícina palca</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Yard</source>
        <translation>Yard</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Angstrom</source>
        <translation>Angstrom</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Nanometer</source>
        <translation>Nanometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Micron</source>
        <translation>Mikrón</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decimeter</source>
        <translation>Decimeter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Decameter</source>
        <translation>Dekameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Hectometer</source>
        <translation>Hektometer</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Gigameter</source>
        <translation>Gigameter</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Astro</source>
        <translation>Astro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Lightyear</source>
        <translation>Svetelný rok</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Parsec</source>
        <translation>Parsec</translation>
    </message>
</context>
<context>
    <name>RColor</name>
    <message>
        <location filename="../src/core/RColor.cpp" line="+288"/>
        <source>By Layer</source>
        <translation>Podľa vrstvy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Podľa Bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Red</source>
        <translation>Červená</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Green</source>
        <translation>Zelená</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Blue</source>
        <translation>Modrá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Cyan</source>
        <translation>Zelenomodrá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Magenta</source>
        <translation>Fialová</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Yellow</source>
        <translation>Žltá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Orange</source>
        <translation>Oranžová</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Red</source>
        <translation>Tmavočervená</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Green</source>
        <translation>Tmavozelená</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Blue</source>
        <translation>Tmavomodrá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Cyan</source>
        <translation>Tmavoazúrová</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Magenta</source>
        <translation>Tmavofialová</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dark Yellow</source>
        <translation>Tmavožltá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black</source>
        <translation>Čierna</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gray</source>
        <translation>Šedá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Light Gray</source>
        <translation>Svetlošedá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>White</source>
        <translation>Biela</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Others...</source>
        <translation>Ďalšie...</translation>
    </message>
</context>
<context>
    <name>RDocumentVariables</name>
    <message>
        <location filename="../src/core/RDocumentVariables.cpp" line="+45"/>
        <source>Current Layer ID</source>
        <translation>ID aktuálnej vrstvy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drawing Unit</source>
        <translation>Jednotka kreslenia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Typ čiary Mierka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Dimension Font</source>
        <translation>Rozmer písma</translation>
    </message>
</context>
<context>
    <name>REntity</name>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="+92"/>
        <source>Block</source>
        <translation>Blok</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+73"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Position</source>
        <translation>Pozícia</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="+65"/>
        <source>Pixel Unit</source>
        <translation>Jednotka pixel</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="+82"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+72"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location line="+0"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Origin</source>
        <translation>Zdroj</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+8"/>
        <location line="+2"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+3"/>
        <location filename="../src/core/RLayout.cpp" line="-11"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location line="+3"/>
        <location filename="../src/core/RTextBasedEntity.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-9"/>
        <location line="+10"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layout</source>
        <translation>Usporiadanie</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceEntity.cpp" line="-2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-7"/>
        <source>Scale</source>
        <translation>Mierka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Angle</source>
        <translation>Uhol</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Columns</source>
        <translation>Stĺpce</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Rows</source>
        <translation>Riadky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Column Spacing</source>
        <translation>Rozostup stĺpcov</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Row Spacing</source>
        <translation>Rozostup riadkov</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Attributes</source>
        <translation>Popisy</translation>
    </message>
    <message>
        <location filename="../src/core/REntity.cpp" line="+91"/>
        <location filename="../src/core/RObject.cpp" line="+67"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Block ID</source>
        <translation>ID bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Layer</source>
        <translation>Vrstva</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+102"/>
        <source>Linetype</source>
        <translation>Typ čiary</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Linetype Scale</source>
        <translation>Mierka typu čiary</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Lineweight</source>
        <translation>Hrúbka čiary</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayer.cpp" line="-2"/>
        <source>Color</source>
        <translation>Farba</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Displayed Color</source>
        <translation>Farba zobrazenia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Draw Order</source>
        <translation>Poradové číslo prvku</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Boundary</source>
        <translation>Ohraničenie</translation>
    </message>
    <message>
        <location line="-3"/>
        <location filename="../src/core/RLayout.cpp" line="+3"/>
        <source>Left</source>
        <translation>Ľavý</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Bottom</source>
        <translation>Spodok</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Right</source>
        <translation>Pravý</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Top</source>
        <translation>Vrch</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <source>Size</source>
        <translation>Rozmer</translation>
    </message>
    <message>
        <location line="-1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="-2"/>
        <source>Width</source>
        <translation>Šírka</translation>
    </message>
    <message>
        <location line="+1"/>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <location filename="../src/core/RViewportEntity.cpp" line="+1"/>
        <source>Height</source>
        <translation>Výška</translation>
    </message>
    <message>
        <location filename="../src/core/RObject.cpp" line="-1"/>
        <location filename="../src/core/RPropertyTypeId.cpp" line="+151"/>
        <source>Custom</source>
        <translation>Vlastné</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Handle</source>
        <translation>Identifikátor</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Protected</source>
        <translation>Chránené</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Selected</source>
        <translation>Vybrané</translation>
    </message>
    <message>
        <location filename="../src/core/RTextBasedEntity.cpp" line="-3"/>
        <source>Simple</source>
        <translation>Jednoduché</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Text Position</source>
        <translation>Pozícia textu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plain Text</source>
        <translation>Čistý text</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Font Name</source>
        <translation>Typ písma</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Height</source>
        <translation>Výška textu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Text Angle</source>
        <translation>Sklon textu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>X Scale</source>
        <translation>X Mierka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bold</source>
        <translation>Tučné</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Italic</source>
        <translation>Šikmé</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Line Spacing</source>
        <translation>Riadkovanie</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>Alignment</source>
        <translation>Zarovnanie</translation>
    </message>
    <message>
        <location line="-1"/>
        <source>Horizontal</source>
        <translation>Vodorovne</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Vertical</source>
        <translation>Zvisle</translation>
    </message>
    <message>
        <location filename="../src/core/RViewportEntity.cpp" line="+2"/>
        <source>Rotation</source>
        <translation>Rotácia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>On</source>
        <translation>Zapnuté</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Center</source>
        <translation>Zobraziť na stred</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>View Target</source>
        <translation>Zobraziť Cieľ</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Overall</source>
        <translation>Celkovo</translation>
    </message>
    <message>
        <location filename="../src/core/RBlock.cpp" line="-6"/>
        <location filename="../src/core/RLayer.cpp" line="-8"/>
        <location filename="../src/core/RLayerState.cpp" line="+46"/>
        <location filename="../src/core/RLayout.cpp" line="-24"/>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Skryté</translation>
    </message>
    <message>
        <location filename="../src/core/RLayer.cpp" line="+1"/>
        <source>Off</source>
        <translation>Vypnúť</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Frozen</source>
        <translation>Zmrazená</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Locked</source>
        <translation>Uzamknuté</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Collapsed</source>
        <translation>Zvinuté</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plottable</source>
        <translation>Môže tlačiť</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Snappable</source>
        <translation>Môže prichytávať</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Off is Freeze</source>
        <translation>Zmrazenie vypnuté</translation>
    </message>
    <message>
        <location filename="../src/core/RLayout.cpp" line="+1"/>
        <source>Tab Order</source>
        <translation>Poradie aktivácie</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Limits</source>
        <translation>Minimum</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Limits</source>
        <translation>Maximum</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Insertion Base</source>
        <translation>Vloženie Základu</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Min Extents</source>
        <translation>Minimálne</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Max Extents</source>
        <translation>Maximálne</translation>
    </message>
    <message>
        <location filename="../src/core/RBlockReferenceData.cpp" line="+655"/>
        <source>Circular (recursive) block referencing detected:</source>
        <translation>Zistený kruhový (rekurzívny) blok:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block name:</source>
        <translation>Názov bloku:</translation>
    </message>
</context>
<context>
    <name>RGuiAction</name>
    <message>
        <location filename="../src/core/RGuiAction.cpp" line="+186"/>
        <source>Requires selection</source>
        <translation>Vyžaduje výber</translation>
    </message>
</context>
<context>
    <name>RLayer</name>
    <message>
        <source>Name</source>
        <translation type="vanished">Názov</translation>
    </message>
    <message>
        <source>Frozen</source>
        <translation type="vanished">Zmrazená</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation type="vanished">Skryté</translation>
    </message>
    <message>
        <source>Locked</source>
        <translation type="vanished">Zamknutá</translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="vanished">Farba</translation>
    </message>
    <message>
        <source>Linetype</source>
        <translation type="vanished">Typ čiary</translation>
    </message>
    <message>
        <source>Lineweight</source>
        <translation type="vanished">Hrúbka čiary</translation>
    </message>
</context>
<context>
    <name>RLinetype</name>
    <message>
        <location filename="../src/core/RLinetype.cpp" line="+48"/>
        <source>Name</source>
        <translation>Názov</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Metric</source>
        <translation>Metrické</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pattern</source>
        <translation>Vzor</translation>
    </message>
</context>
<context>
    <name>RLinetypePattern</name>
    <message>
        <location filename="../src/core/RLinetypePattern.cpp" line="+856"/>
        <source>By Layer</source>
        <translation>Podľa vrstvy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Podľa Bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Continuous</source>
        <translation>Súvislá</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Border</source>
        <translation>Okrajová</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Center</source>
        <translation>Stredová</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dash dot</source>
        <translation>Bodkočiarkovaná</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dashed</source>
        <translation>Prerušovaná čiara</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Divide</source>
        <translation>Oddelová</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Dot</source>
        <translation>Bodkovaná</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Hidden</source>
        <translation>Skrytá</translation>
    </message>
    <message>
        <location line="+2"/>
        <location line="+1"/>
        <location line="+1"/>
        <source>Phantom</source>
        <translation>Phantom</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>ISO dash</source>
        <translation>ISO Prerušovaná</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash space</source>
        <translation>ISO čiarka medzera</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash dot</source>
        <translation>ISO dlhá-čiarka bodka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-dot</source>
        <translation>ISO dlhá-čiarka 2-bodky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash triple-dot</source>
        <translation>ISO dlhá-čiarka 3-bodky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dot</source>
        <translation>ISO bodkovaná</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash short-dash</source>
        <translation>ISO dlhá-čiarka krátka-čiarka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO long-dash double-short-dash</source>
        <translation>ISO dlhá-čiarka 2-krátke-čiarky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash dot</source>
        <translation>ISO bodkočiarkovaná</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash dot</source>
        <translation>ISO 2-čiarky bodka</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash double-dot</source>
        <translation>ISO čiarka 2-bodky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash double-dot</source>
        <translation>ISO 2-čiarky 2-bodky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO dash triple-dot</source>
        <translation>ISO čiarka 3-bodky</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>ISO double-dash triple-dot</source>
        <translation>ISO 2-čiarky 3-bodky</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hot Water Supply</source>
        <translation>prívod teplej vody</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Hot Water</source>
        <translation>Teplá voda</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Gas Line</source>
        <translation>Prívod plynu</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Batting</source>
        <translation>Izolácia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Zig Zag</source>
        <translation>Cik-cakovitá</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Tracks</source>
        <translation>Železnica</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 1</source>
        <translation>Plot typ 1</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Fenceline 2</source>
        <translation>Plot typ 2</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Drainage</source>
        <translation>Kanalizácia</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Drainage Reversed</source>
        <translation>Kanalizácia opačná</translation>
    </message>
</context>
<context>
    <name>RLineweight</name>
    <message>
        <location filename="../src/core/RLineweight.cpp" line="+35"/>
        <source>By Layer</source>
        <translation>Podľa vrstvy</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>By Block</source>
        <translation>Podľa Bloku</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Default</source>
        <translation>Predvolené</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.00mm</source>
        <translation>0.00mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.05mm</source>
        <translation>0.05mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.09mm</source>
        <translation>0.09mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.13mm (ISO)</source>
        <translation>0.13mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.15mm</source>
        <translation>0.15mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.18mm (ISO)</source>
        <translation>0.18mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.20mm</source>
        <translation>0.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.25mm (ISO)</source>
        <translation>0.25mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.30mm</source>
        <translation>0.30mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.35mm (ISO)</source>
        <translation>0.35mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.40mm</source>
        <translation>0.40mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.50mm (ISO)</source>
        <translation>0.50mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.53mm</source>
        <translation>0.53mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.60mm</source>
        <translation>0.60mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.70mm (ISO)</source>
        <translation>0.70mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.80mm</source>
        <translation>0.80mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>0.90mm</source>
        <translation>0.90mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.00mm (ISO)</source>
        <translation>1.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.06mm</source>
        <translation>1.06mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.20mm</source>
        <translation>1.20mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.40mm (ISO)</source>
        <translation>1.40mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>1.58mm</source>
        <translation>1.58mm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.00mm (ISO)</source>
        <translation>2.00mm (ISO)</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>2.11mm</source>
        <translation>2.11mm</translation>
    </message>
</context>
<context>
    <name>RObject</name>
    <message>
        <source>Custom</source>
        <translation type="vanished">Vlastné</translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="vanished">Typ</translation>
    </message>
    <message>
        <source>Handle</source>
        <translation type="vanished">Identifikátor</translation>
    </message>
    <message>
        <source>Protected</source>
        <translation type="vanished">Chránené</translation>
    </message>
</context>
</TS>
